==> deepin-launchpad-debug-2.0.14-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-launchpad/dde-launchpad/.qt/rcc/qrc_launchpadcommon_raw_res_0.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qml.qrc
  0x0,0x0,0x1,0x18,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x60,0x3,0x75,0x8,0x0,0xd2,0xc,0x26,0x18,0x70,0x6f,0x3,
  0xa0,0x92,0x24,0xc5,0x51,0x4f,0x61,0x25,0x6d,0xd1,0x9c,0x7e,0xf3,0xc1,0x93,0x8d,
  0xff,0xfe,0xaf,0xf7,0x2,0x40,0xa2,0x28,0xb,0x3b,0x22,0x8d,0x97,0xc3,0xee,0xa,
  0xdd,0xbe,0xa8,0xb1,0x92,0xcd,0xcf,0xc7,0x28,0xa8,0xd6,0x5b,0x49,0xe9,0x45,0xfe,
  0xef,0x7d,0x5c,0x9c,0xa,0x2b,0xd9,0xad,0x70,0xfa,0x76,0x93,0xb1,0x75,0xe5,0xb7,
  0xc7,0x3d,0x57,0xfe,0xad,0xef,0xf2,0xa7,0xb6,0x68,0x21,0x13,0x9,0xec,0x1a,0x22,
  0xee,0xb6,0x73,0x8,0xa7,0xd3,0x9e,0xad,0x15,0x10,0x57,0x86,0x1a,0x78,0x94,0x8e,
  0x87,0xc8,0xc3,0x43,0x9e,0xc,0x7b,0xde,0x30,0x76,0x3c,0xca,0x9,0x49,0x3e,0xe4,
  0xdb,0xc,0xd6,0x10,0x25,0xbf,0x3a,0x86,0x92,0xa4,0xcc,0xf7,0x69,0xc4,0xc9,0x42,
  0x76,0x4,0x26,0x20,0x16,0x3b,0xdb,0x52,0xb0,0xae,0xa7,0xf4,0xed,0xe9,0x8,0x80,
  0x44,0x51,0x96,0x23,0x30,0xa0,0xa1,0x4a,0x40,0x42,0x1,0x15,0x73,0xa,0x59,0xe,
  0x30,0x82,0x5,0x31,0xdb,0xf4,0xb3,0x48,0xe2,0x75,0xf2,0x20,0x23,0xfe,0x12,0xf0,
  0xe1,0x7b,0x5c,0xf7,0x33,0xea,0x88,0x3c,0x69,0x97,0x85,0x1a,0x46,0x2,0xb2,0x93,
  0x11,0x4d,0x41,0x80,0xcc,0xa0,0x53,0xee,0x38,0x22,0xb4,0x59,0xcf,0x7c,0xd,0x8d,
  0x27,0xe1,0x5,0xb4,0x35,0x96,0x42,0x19,0x72,0x64,0x4,0x22,0x70,0x7a,0xb9,0xf,
  0x64,0x8f,0x89,0xbe,0x14,0x1,0x45,0x8d,0x40,0x88,0x1,0x71,0x7c,0xac,0xd,0xbb,
  0x7e,0x9,0x63,0x82,0x50,0xdd,0x22,0xca,0x36,0xa8,0xd4,0x29,0x12,0xb9,0xc2,0x8a,
  0xb6,0xa0,0x33,0xf6,0x81,0x1b,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // launchpad
  0x0,0x9,
  0xc,0x49,0x13,0x74,
  0x0,0x6c,
  0x0,0x61,0x0,0x75,0x0,0x6e,0x0,0x63,0x0,0x68,0x0,0x70,0x0,0x61,0x0,0x64,
    // qml.qrc
  0x0,0x7,
  0x8,0x3f,0x58,0x63,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x2e,0x0,0x71,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0x1c,0x9d,0x96,0x28,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0x1c,0x9d,0x96,0x28,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0x1c,0x9d,0x96,0x28,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9a,0x1c,0x9d,0x96,0x28,
  // :/qt/qml/org/deepin
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9a,0x1c,0x9d,0x96,0x28,
  // :/qt/qml/org/deepin/launchpad
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9a,0x1c,0x9d,0x96,0x28,
  // :/qt/qml/org/deepin/launchpad/qml.qrc
  0x0,0x0,0x0,0x4c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x1c,0x9d,0x96,0x28,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_launchpadcommon_raw_res_0)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_launchpadcommon_raw_res_0)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_launchpadcommon_raw_res_0)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_launchpadcommon_raw_res_0)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_launchpadcommon_raw_res_0)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_launchpadcommon_raw_res_0)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-launchpad-debug-2.0.16-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-launchpad/dde-launchpad/.qt/rcc/qrc_launchpadcommon_raw_res_0.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qml.qrc
  0x0,0x0,0x1,0x18,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x60,0x3,0x75,0x8,0x0,0xd2,0xc,0x26,0x18,0x70,0x6f,0x3,
  0xa0,0x92,0x24,0xc5,0x51,0x4f,0x61,0x25,0x6d,0xd1,0x9c,0x7e,0xf3,0xc1,0x93,0x8d,
  0xff,0xfe,0xaf,0xf7,0x2,0x40,0xa2,0x28,0xb,0x3b,0x22,0x8d,0x97,0xc3,0xee,0xa,
  0xdd,0xbe,0xa8,0xb1,0x92,0xcd,0xcf,0xc7,0x28,0xa8,0xd6,0x5b,0x49,0xe9,0x45,0xfe,
  0xef,0x7d,0x5c,0x9c,0xa,0x2b,0xd9,0xad,0x70,0xfa,0x76,0x93,0xb1,0x75,0xe5,0xb7,
  0xc7,0x3d,0x57,0xfe,0xad,0xef,0xf2,0xa7,0xb6,0x68,0x21,0x13,0x9,0xec,0x1a,0x22,
  0xee,0xb6,0x73,0x8,0xa7,0xd3,0x9e,0xad,0x15,0x10,0x57,0x86,0x1a,0x78,0x94,0x8e,
  0x87,0xc8,0xc3,0x43,0x9e,0xc,0x7b,0xde,0x30,0x76,0x3c,0xca,0x9,0x49,0x3e,0xe4,
  0xdb,0xc,0xd6,0x10,0x25,0xbf,0x3a,0x86,0x92,0xa4,0xcc,0xf7,0x69,0xc4,0xc9,0x42,
  0x76,0x4,0x26,0x20,0x16,0x3b,0xdb,0x52,0xb0,0xae,0xa7,0xf4,0xed,0xe9,0x8,0x80,
  0x44,0x51,0x96,0x23,0x30,0xa0,0xa1,0x4a,0x40,0x42,0x1,0x15,0x73,0xa,0x59,0xe,
  0x30,0x82,0x5,0x31,0xdb,0xf4,0xb3,0x48,0xe2,0x75,0xf2,0x20,0x23,0xfe,0x12,0xf0,
  0xe1,0x7b,0x5c,0xf7,0x33,0xea,0x88,0x3c,0x69,0x97,0x85,0x1a,0x46,0x2,0xb2,0x93,
  0x11,0x4d,0x41,0x80,0xcc,0xa0,0x53,0xee,0x38,0x22,0xb4,0x59,0xcf,0x7c,0xd,0x8d,
  0x27,0xe1,0x5,0xb4,0x35,0x96,0x42,0x19,0x72,0x64,0x4,0x22,0x70,0x7a,0xb9,0xf,
  0x64,0x8f,0x89,0xbe,0x14,0x1,0x45,0x8d,0x40,0x88,0x1,0x71,0x7c,0xac,0xd,0xbb,
  0x7e,0x9,0x63,0x82,0x50,0xdd,0x22,0xca,0x36,0xa8,0xd4,0x29,0x12,0xb9,0xc2,0x8a,
  0xb6,0xa0,0x33,0xf6,0x81,0x1b,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // deepin
  0x0,0x6,
  0x6,0xab,0xc6,0xfe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,
    // launchpad
  0x0,0x9,
  0xc,0x49,0x13,0x74,
  0x0,0x6c,
  0x0,0x61,0x0,0x75,0x0,0x6e,0x0,0x63,0x0,0x68,0x0,0x70,0x0,0x61,0x0,0x64,
    // qml.qrc
  0x0,0x7,
  0x8,0x3f,0x58,0x63,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x2e,0x0,0x71,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0x5f,0x5f,0x79,0xe0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0x5f,0x5f,0x79,0xe0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0x5f,0x5f,0x79,0xe0,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9a,0x5f,0x5f,0x79,0xe0,
  // :/qt/qml/org/deepin
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9a,0x5f,0x5f,0x79,0xe0,
  // :/qt/qml/org/deepin/launchpad
  0x0,0x0,0x0,0x34,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9a,0x5f,0x5f,0x79,0xe0,
  // :/qt/qml/org/deepin/launchpad/qml.qrc
  0x0,0x0,0x0,0x4c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x5f,0x5f,0x79,0xe0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_launchpadcommon_raw_res_0)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_launchpadcommon_raw_res_0)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_launchpadcommon_raw_res_0)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_launchpadcommon_raw_res_0)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_launchpadcommon_raw_res_0)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_launchpadcommon_raw_res_0)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
